@@ -1941,7 +1941,13 @@ eval_code2(PyCodeObject *co, PyObject *globals, PyObject *locals,
 		       callable object.
 		    */
 		    if (PyCFunction_Check(func)) {
-			    if (PyCFunction_GET_FLAGS(func) == 0) {
+			    int flags = PyCFunction_GET_FLAGS(func);
+			    if (flags == METH_VARARGS) {
+				    PyObject *callargs;
+				    callargs = load_args(&stack_pointer, na);
+				    x = call_cfunction(func, callargs, NULL);
+				    Py_XDECREF(callargs); 
+			    } else if (flags == 0) {
 				    x = fast_cfunction(func,
 						       &stack_pointer, na);
 			    } else {
@@ -2806,8 +2812,9 @@ call_object(PyObject *func, PyObject *arg, PyObject *kw)
 	else if ((call = func->ob_type->tp_call) != NULL)
 		result = (*call)(func, arg, kw);
 	else {
-		PyErr_Format(PyExc_TypeError, "object is not callable: %s",
-			     PyString_AS_STRING(PyObject_Repr(func)));
+		PyErr_Format(PyExc_TypeError,
+			     "object of type '%.100s' is not callable",
+			     func->ob_type->tp_name);
 		return NULL;
 	}
         if (result == NULL && !PyErr_Occurred())
